<script src="{{ url_for('static', filename='vendor/jquery/dist/jquery.min.js') }}" type="text/javascript"></script>

<script src="{{ url_for('static', filename='vendor/bootstrap/dist/js/bootstrap.min.js') }}" type="text/javascript"></script>
